@@ -1,3 +1,5 @@
 pub mod compression;
 pub mod cors;
 pub mod file_server;
+pub mod logger;
+pub mod proxy;
